<?php declare(strict_types=1);

namespace App\Domains\Driver\Model;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use App\Domains\CoreApp\Model\ModelAbstract;
use App\Domains\User\Model\User as UserModel;
use App\Domains\Driver\Model\Builder\Driver as Builder;
use App\Domains\Driver\Model\Collection\Driver as Collection;
use App\Domains\Driver\Test\Factory\Driver as TestFactory;

class Driver extends ModelAbstract
{
    use HasFactory;

    /**
     * @var string
     */
    protected $table = 'driver';

    /**
     * @const string
     */
    public const TABLE = 'driver';

    /**
     * @const string
     */
    public const FOREIGN = 'driver_id';

    /**
     * @var array<string, string>
     */
    protected $casts = [
        'enabled' => 'boolean',
    ];

    public function newCollection(array $models = []): Collection
    {
        return new Collection($models);
    }

    public function newEloquentBuilder($query): Builder
    {
        return new Builder($query);
    }

    protected static function newFactory(): TestFactory
    {
        return TestFactory::new();
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function user(): BelongsTo
    {
        return $this->belongsTo(UserModel::class, UserModel::FOREIGN);
    }
}
